==> typo3_src-4.7.1.tar.gz: typo3_src-4.7.1/typo3/sysext/fluid/Classes/Core/Widget/Exception/RenderingContextNotFoundException.php <==
<?php

/*
 * This script is backported from the FLOW3 package "TYPO3.Fluid".        *
 *                                                                        *
 * It is free software; you can redistribute it and/or modify it under    *
 * the terms of the GNU Lesser General Public License, either version 3   *
 *  of the License, or (at your option) any later version.                *
 *                                                                        *
 *                                                                        *
 * This script is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHAN-    *
 * TABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser       *
 * General Public License for more details.                               *
 *                                                                        *
 * You should have received a copy of the GNU Lesser General Public       *
 * License along with the script.                                         *
 * If not, see http://www.gnu.org/licenses/lgpl.html                      *
 *                                                                        *
 * The TYPO3 project - inspiring people to share!                         *
 *                                                                        */

/**
 * An exception if no widget context could be found inside the AjaxWidgetContextHolder.
 *
 */
class Tx_Fluid_Core_Widget_Exception_RenderingContextNotFoundException extends Tx_Fluid_Core_Widget_Exception {
}
?>

==> typo3_src-6.2.31.tar.gz: typo3_src-6.2.31/typo3/sysext/fluid/Classes/Core/Widget/Exception/RenderingContextNotFoundException.php <==
<?php
namespace TYPO3\CMS\Fluid\Core\Widget\Exception;

/*
 * This script is backported from the TYPO3 Flow package "TYPO3.Fluid".   *
 *                                                                        *
 * It is free software; you can redistribute it and/or modify it under    *
 * the terms of the GNU Lesser General Public License, either version 3   *
 *  of the License, or (at your option) any later version.                *
 *                                                                        *
 *                                                                        *
 * This script is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHAN-    *
 * TABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser       *
 * General Public License for more details.                               *
 *                                                                        *
 * You should have received a copy of the GNU Lesser General Public       *
 * License along with the script.                                         *
 * If not, see http://www.gnu.org/licenses/lgpl.html                      *
 *                                                                        *
 * The TYPO3 project - inspiring people to share!                         *
 *                                                                        */
/**
 * An exception if no widget context could be found inside the AjaxWidgetContextHolder.
 */
class RenderingContextNotFoundException extends \TYPO3\CMS\Fluid\Core\Widget\Exception {

}
